==> phplist-2.10.14p1.tgz: lists/admin/lan/es/home.php <==
<?php

$lan = array(
  'Your database is out of date, please make sure to upgrade' => 'Su
  base de datos no est&aacute; al d&iacute;a, por favor actual&iacute;cela',
  'Your version' => 'Su versi&oacute;n',
  'Latest version' => '&Uacute;ltima versi&oacute;n',
  'phplist version' => 'Versi&oacute;n de <a href="http://www.phplist.com">phplist</a>',
  'Database has not been initialised' => 'No se ha inicializado la
  base de datos',
  'go to' => 'ir a',
  'Initialise Database' => 'Initializar base de datos',
  'to continue' => 'para continuar',
  'A new version of PHPlist is available!' => '&#161;Hay una nueva
  versi&oacute;n de phplist disponible!',
  'The new version may have fixed security issues,<br/>so it is
  recommended to upgrade as soon as possible' => 'La nueva
  versi&oacute;n puede haber solucionado problemas de
  seguridad,<br/>por lo que se recomienda actualizar lo antes posible',
  'View what has changed' => 'Ver los cambios',
  'Download' => 'Descargar',
  'System Functions' => 'Funciones del sistema',
  'Setup ' => 'Instalaci&oacute;n',
  'Check Database structure' => 'Comprobar la estructura de la base de
  datos',
  'View the eventlog' => 'Ver el registro de eventos',
  'Configuration functions' => 'Funciones de configuraci&oacute;n',
  'Configure Attributes' => 'Configurar atributos',
  'Control values for' => 'Valores de control para',
  'Control values for' => 'Valores de control para',
  'Control values for' => 'Valores de control para',
  'Configure Subscribe pages' => 'Configurar p&aacute;ginas de inscripci&oacute;n',
  'List and user functions' => 'Funciones de lista y usuario',
  'List the current lists' => 'Enumerar las listas actuales',
  'List all Users' => 'Enumerar todos los usuarios',
  'Reconcile the user database' => 'Conciliar la base de datos de usuarios',
  'Import Users' => 'Importar usuarios',
  'Export Users' => 'Exportar usuarios',
  'Administrator functions' => 'Funciones de administrador',
  'Add, edit and remove Administrators' => 'A&ntilde;adir, editar y
  eliminar administradores',
  'Configure attributes for administrators' => 'Configurar atributos
  para los administradores',
  'Message functions' => 'Funciones de mensaje',
  'Configure Templates' => 'Configurar plantillas',
  'List all Messages' => 'Enumerar todos los mensajes',
  'Process the Message queue' => 'Procesar la cola de mensajes',
  'RSS Functions' => 'Funciones de RSS',
  'Get RSS feeds' => 'Obtener canales RSS',
  'View RSS items' => 'Ver elementos RSS',
  'Plugins' => 'M&oacute;dulos (plugins)',
  'Upgrade' => 'Actualizar',
'Change your details (e.g. password)' => 'Cambie sus datos (p. ej. la contrase&ntilde;a)',
'You have set TEST in config.php to 1, so it will only show what would
  be sent' => 'Estableci&oacute; TEST = 1 en config.php, de modo que
  se limitar&aacute; a mostrar lo que se enviar&iacute;a',

);

?>

==> phplist-2.10.19p0.tgz: lists/admin/lan/es/home.php <==
<?php

$lan = array(
  'Your database is out of date, please make sure to upgrade' => 'Su
  base de datos no est&aacute; al d&iacute;a, por favor actual&iacute;cela',
  'Your version' => 'Su versi&oacute;n',
  'Latest version' => '&Uacute;ltima versi&oacute;n',
  'phplist version' => 'Versi&oacute;n de <a href="http://www.phplist.com">phplist</a>',
  'Database has not been initialised' => 'No se ha inicializado la
  base de datos',
  'go to' => 'ir a',
  'Initialise Database' => 'Initializar base de datos',
  'to continue' => 'para continuar',
  'A new version of PHPlist is available!' => '&#161;Hay una nueva
  versi&oacute;n de phplist disponible!',
  'The new version may have fixed security issues,<br/>so it is
  recommended to upgrade as soon as possible' => 'La nueva
  versi&oacute;n puede haber solucionado problemas de
  seguridad,<br/>por lo que se recomienda actualizar lo antes posible',
  'View what has changed' => 'Ver los cambios',
  'Download' => 'Descargar',
  'System Functions' => 'Funciones del sistema',
  'Setup ' => 'Instalaci&oacute;n',
  'Check Database structure' => 'Comprobar la estructura de la base de
  datos',
  'View the eventlog' => 'Ver el registro de eventos',
  'Configuration functions' => 'Funciones de configuraci&oacute;n',
  'Configure Attributes' => 'Configurar atributos',
  'Control values for' => 'Valores de control para',
  'Control values for' => 'Valores de control para',
  'Control values for' => 'Valores de control para',
  'Configure Subscribe pages' => 'Configurar p&aacute;ginas de inscripci&oacute;n',
  'List and user functions' => 'Funciones de lista y usuario',
  'List the current lists' => 'Enumerar las listas actuales',
  'List all Users' => 'Enumerar todos los usuarios',
  'Reconcile the user database' => 'Conciliar la base de datos de usuarios',
  'Import Users' => 'Importar usuarios',
  'Export Users' => 'Exportar usuarios',
  'Administrator functions' => 'Funciones de administrador',
  'Add, edit and remove Administrators' => 'A&ntilde;adir, editar y
  eliminar administradores',
  'Configure attributes for administrators' => 'Configurar atributos
  para los administradores',
  'Message functions' => 'Funciones de mensaje',
  'Configure Templates' => 'Configurar patrones',
  'List all Messages' => 'Enumerar todos los mensajes',
  'Process the Message queue' => 'Procesar la cola de mensajes',
  'RSS Functions' => 'Funciones de RSS',
  'Get RSS feeds' => 'Obtener canales RSS',
  'View RSS items' => 'Ver elementos RSS',
  'Plugins' => 'M&oacute;dulos (plugins)',
  'Upgrade' => 'Actualizar',
'Change your details (e.g. password)' => 'Cambie sus datos (p. ej. la contrase&ntilde;a)',
'You have set TEST in config.php to 1, so it will only show what would
  be sent' => 'Estableci&oacute; TEST = 1 en config.php, de modo que
  se limitar&aacute; a mostrar lo que se enviar&iacute;a',

);

?>
